aboutsummaryrefslogtreecommitdiff
path: root/common/ucnv_cnv.h
diff options
context:
space:
mode:
authorClaire Ho <chinglanho@gmail.com>2009-11-24 14:23:02 -0800
committerClaire Ho <chinglanho@gmail.com>2009-11-24 14:27:49 -0800
commit85bf2e2fbc60a9f938064abc8127d61da7d19882 (patch)
tree4fdc7e4eb31841bb565de7307d08e3c33148b5e6 /common/ucnv_cnv.h
parent48a58c978aa6ddd00cec768a9e85807415551d4e (diff)
downloadicu4c-85bf2e2fbc60a9f938064abc8127d61da7d19882.tar.gz
Merge ICU421 to Android.
Bug: 1823720 Reviewed-by: jessewilson@google.com, enh@google.com CC: Signed-off-by:
Diffstat (limited to 'common/ucnv_cnv.h')
-rw-r--r--common/ucnv_cnv.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/common/ucnv_cnv.h b/common/ucnv_cnv.h
index a51faaf2..cba24d06 100644
--- a/common/ucnv_cnv.h
+++ b/common/ucnv_cnv.h
@@ -1,6 +1,6 @@
/*
**********************************************************************
-* Copyright (C) 1999-2007, International Business Machines
+* Copyright (C) 1999-2009, International Business Machines
* Corporation and others. All Rights Reserved.
**********************************************************************
*
@@ -49,9 +49,11 @@ typedef struct UConverterSharedData UConverterSharedData;
typedef struct {
int32_t size; /* sizeof(UConverterLoadArgs) */
int32_t nestedLoads; /* count nested ucnv_load() calls */
- int32_t reserved; /* reserved - for good alignment of the pointers */
+ UBool onlyTestIsLoadable; /* input: don't actually load */
+ UBool reserved0; /* reserved - for good alignment of the pointers */
+ int16_t reserved; /* reserved - for good alignment of the pointers */
uint32_t options;
- const char *pkg, *name;
+ const char *pkg, *name, *locale;
} UConverterLoadArgs;
typedef void (*UConverterLoad) (UConverterSharedData *sharedData,
@@ -59,7 +61,7 @@ typedef void (*UConverterLoad) (UConverterSharedData *sharedData,
const uint8_t *raw, UErrorCode *pErrorCode);
typedef void (*UConverterUnload) (UConverterSharedData *sharedData);
-typedef void (*UConverterOpen) (UConverter *cnv, const char *name, const char *locale,uint32_t options, UErrorCode *pErrorCode);
+typedef void (*UConverterOpen) (UConverter *cnv, UConverterLoadArgs *pArgs, UErrorCode *pErrorCode);
typedef void (*UConverterClose) (UConverter *cnv);
typedef enum UConverterResetChoice {